/*
 * SPDX-License-Identifier: LGPL-2.1
 */
#define TSLIB_DECLARE_MODULE(name) \
	TSAPI struct tslib_module_info *name##_mod_init(struct tsdev *dev, const char *params)

TSLIB_DECLARE_MODULE(linear);
TSLIB_DECLARE_MODULE(dejitter);
TSLIB_DECLARE_MODULE(linear_h2200);
TSLIB_DECLARE_MODULE(variance);
TSLIB_DECLARE_MODULE(median);
TSLIB_DECLARE_MODULE(pthres);
TSLIB_DECLARE_MODULE(debounce);
TSLIB_DECLARE_MODULE(skip);
TSLIB_DECLARE_MODULE(iir);
TSLIB_DECLARE_MODULE(lowpass);

TSLIB_DECLARE_MODULE(arctic2);
TSLIB_DECLARE_MODULE(collie);
TSLIB_DECLARE_MODULE(corgi);
TSLIB_DECLARE_MODULE(cy8mrln_palmpre);
TSLIB_DECLARE_MODULE(dmc);
TSLIB_DECLARE_MODULE(dmc_dus3000);
TSLIB_DECLARE_MODULE(galax);
TSLIB_DECLARE_MODULE(h3600);
TSLIB_DECLARE_MODULE(input);
TSLIB_DECLARE_MODULE(mk712);
TSLIB_DECLARE_MODULE(tatung);
TSLIB_DECLARE_MODULE(touchkit);
TSLIB_DECLARE_MODULE(ucb1x00);
TSLIB_DECLARE_MODULE(waveshare);
